@@ -33,12 +33,6 @@
 #include <meta/meta-background.h>
 #include "meta-background-actor-private.h"
 
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-#define TEXTURE_FORMAT COGL_PIXEL_FORMAT_BGRA_8888_PRE
-#else
-#define TEXTURE_FORMAT COGL_PIXEL_FORMAT_ARGB_8888_PRE
-#endif
-
 #define TEXTURE_LOOKUP_SHADER_DECLARATIONS                                     \
 "uniform vec2 pixel_step;\n"                                                   \
 "vec4 apply_blur(in sampler2D texture, in vec2 coordinates) {\n"               \
@@ -70,14 +64,16 @@
 "cogl_texel = apply_blur(cogl_sampler, cogl_tex_coord.st);\n"
 
 #define FRAGMENT_SHADER_DECLARATIONS                                           \
+"uniform vec2 texture_scale;\n"                                                \
+"uniform vec2 actor_size;\n"                                                   \
+"uniform vec2 offset;\n"                                                       \
 "uniform float brightness;\n"                                                  \
 "uniform float vignette_sharpness;\n"                                          \
 
 #define VIGNETTE_CODE                                                          \
-"float unit_length = 0.5;\n"                                                   \
-"vec2 center = vec2(unit_length, unit_length);\n"                              \
-"vec2 position = cogl_tex_coord_in[0].xy - center;\n"                          \
-"float t = min(length(position), unit_length) / unit_length;\n"                \
+"vec2 position = cogl_tex_coord_in[0].xy * texture_scale - offset;\n"          \
+"float t = length(2.0 * (position / actor_size));\n"                           \
+"t = clamp(t, 0.0, 1.0);\n"                                                    \
 "float pixel_brightness = mix(1.0, 1.0 - vignette_sharpness, t);\n"            \
 "cogl_color_out.rgb = cogl_color_out.rgb * pixel_brightness * brightness;\n"
 
@@ -167,6 +163,7 @@ get_texture_area_and_scale (MetaBackground        *self,
   float texture_width, texture_height;
   float actor_x_scale, actor_y_scale;
   float monitor_x_scale, monitor_y_scale;
+  float x_offset, y_offset;
 
   meta_screen_get_monitor_geometry (priv->screen, priv->monitor, &monitor_geometry);
 
@@ -193,14 +190,40 @@ get_texture_area_and_scale (MetaBackground        *self,
           *texture_y_scale = 1.0 / actor_pixel_rect.height;
           break;
       case G_DESKTOP_BACKGROUND_STYLE_WALLPAPER:
-          /* paint region is whole actor, and the texture
-           * is left unscaled
+          /* The wallpaper should be centered in the middle of all monitors.
+           * Therefore, the textured area is the union of all monitors plus
+           * an additional bit to make up for the texture getting centered.  */
+          meta_screen_get_size (priv->screen, &screen_width, &screen_height);
+
+          /* so start by making the unclipped texture area the whole screen */
+          image_area.width = screen_width;
+          image_area.height = screen_height;
+
+          /* If one of the tiles is already centered in the screen, then that tile
+           * will start tile_size/2.0 before the center of the screen. So find out
+           * how far we are from that ideal and adjust by that offset.
            */
-          image_area = actor_pixel_rect;
-          *texture_x_scale = 1.0 / texture_width;
-          *texture_y_scale = 1.0 / texture_height;
+          x_offset = texture_width - ((int) ((screen_width / 2.0) - (texture_width / 2.0))) % ((int) texture_width);
+          y_offset = texture_height - ((int) ((screen_height / 2.0) - (texture_height / 2.0))) % ((int) texture_height);
+
+          image_area.width += x_offset;
+          image_area.height += y_offset;
+          image_area.x = -x_offset;
+          image_area.y = -y_offset;
+
+          /* now line up with the appropriate monitor */
+          image_area.x -= monitor_geometry.x;
+          image_area.y -= monitor_geometry.y;
+
+          /* and scale to actor */
+          image_area.x *= actor_x_scale;
+          image_area.y *= actor_y_scale;
+          image_area.width *= actor_x_scale;
+          image_area.height *= actor_y_scale;
 
           *texture_area = image_area;
+          *texture_x_scale = 1.0 / texture_width;
+          *texture_y_scale = 1.0 / texture_height;
           break;
       case G_DESKTOP_BACKGROUND_STYLE_CENTERED:
           /* paint region is the original image size centered in the actor,
@@ -352,6 +375,44 @@ set_blur_parameters (MetaBackground  *self,
                                    2, 1, pixel_step);
 }
 
+static void
+set_vignette_parameters (MetaBackground        *self,
+                         ClutterActorBox       *actor_box,
+                         cairo_rectangle_int_t *texture_area,
+                         float                  texture_x_scale,
+                         float                  texture_y_scale)
+{
+  MetaBackgroundPrivate *priv = self->priv;
+  float                  texture_scale[2];
+  float                  actor_size[2];
+  float                  offset[2];
+
+  if (!(priv->effects & META_BACKGROUND_EFFECTS_VIGNETTE))
+    return;
+
+  texture_scale[0] = 1.0 / texture_x_scale;
+  texture_scale[1] = 1.0 / texture_y_scale;
+  actor_size[0] = actor_box->x2 - actor_box->x1;
+  actor_size[1] = actor_box->y2 - actor_box->y1;
+  offset[0] = -texture_area->x + (actor_size[0] / 2.0);
+  offset[1] = -texture_area->y + (actor_size[1] / 2.0);
+
+  cogl_pipeline_set_uniform_float (priv->pipeline,
+                                   cogl_pipeline_get_uniform_location (priv->pipeline,
+                                                                       "texture_scale"),
+                                   2, 1, texture_scale);
+
+  cogl_pipeline_set_uniform_float (priv->pipeline,
+                                   cogl_pipeline_get_uniform_location (priv->pipeline,
+                                                                       "actor_size"),
+                                   2, 1, actor_size);
+
+  cogl_pipeline_set_uniform_float (priv->pipeline,
+                                   cogl_pipeline_get_uniform_location (priv->pipeline,
+                                                                       "offset"),
+                                   2, 1, offset);
+}
+
 static void
 meta_background_paint_content (ClutterContent   *content,
                                ClutterActor     *actor,
@@ -387,6 +448,8 @@ meta_background_paint_content (ClutterContent   *content,
                               &texture_x_scale,
                               &texture_y_scale);
 
+  set_vignette_parameters (self, &actor_box, &texture_area, texture_x_scale, texture_y_scale);
+
   /* Now figure out what to actually paint. We start by clipping the texture area to
    * the actor's bounds.
    */
@@ -932,9 +995,10 @@ meta_background_load_gradient (MetaBackground             *self,
   pixels[5] = second_color->green;
   pixels[6] = second_color->blue;
   pixels[7] = second_color->alpha;
+
   texture = cogl_texture_new_from_data (width, height,
                                         COGL_TEXTURE_NO_SLICING,
-                                        TEXTURE_FORMAT,
+                                        COGL_PIXEL_FORMAT_RGBA_8888,
                                         COGL_PIXEL_FORMAT_ANY,
                                         4,
                                         pixels);
