@@ -93,7 +93,6 @@ struct _MetaDisplay
   
   char *name;
   Display *xdisplay;
-  char *hostname;
 
   Window leader_window;
   Window timestamp_pinging_window;
@@ -461,6 +460,9 @@ void meta_display_queue_autoraise_callback  (MetaDisplay *display,
 void meta_display_remove_autoraise_callback (MetaDisplay *display);
 
 void meta_display_overlay_key_activate (MetaDisplay *display);
+void meta_display_accelerator_activate (MetaDisplay *display,
+                                        guint        action,
+                                        guint        deviceid);
 
 /* In above-tab-keycode.c */
 guint meta_display_get_above_tab_keycode (MetaDisplay *display);
