@@ -48,6 +48,7 @@
 #include <X11/Xatom.h>
 #include <unistd.h>
 #include <string.h>
+
 #ifndef HOST_NAME_MAX
 /* Solaris headers apparently don't define this so do so manually; #326745 */
 #define HOST_NAME_MAX 255
@@ -200,6 +201,19 @@ reload_wm_client_machine (MetaWindow    *window,
 
   meta_verbose ("Window has client machine \"%s\"\n",
                 window->wm_client_machine ? window->wm_client_machine : "unset");
+
+  if (window->wm_client_machine == NULL)
+    {
+      window->is_remote = FALSE;
+    }
+  else
+    {
+      char hostname[HOST_NAME_MAX + 1] = "";
+
+      gethostname (hostname, HOST_NAME_MAX + 1);
+
+      window->is_remote = g_strcmp0 (window->wm_client_machine, hostname) != 0;
+    }
 }
 
 static void
@@ -399,7 +413,6 @@ set_title_text (MetaWindow  *window,
                 Atom         atom,
                 char       **target)
 {
-  char hostname[HOST_NAME_MAX + 1];
   gboolean modified = FALSE;
   
   if (!target)
@@ -416,9 +429,7 @@ set_title_text (MetaWindow  *window,
     }
   /* if WM_CLIENT_MACHINE indicates this machine is on a remote host
    * lets place that hostname in the title */
-  else if (window->wm_client_machine &&
-           !gethostname (hostname, HOST_NAME_MAX + 1) &&
-           strcmp (hostname, window->wm_client_machine))
+  else if (meta_window_is_remote (window))
     {
       *target = g_strdup_printf (_("%s (on %s)"),
                       title, window->wm_client_machine);
