@@ -139,6 +139,11 @@ guint meta_display_add_keybinding    (MetaDisplay         *display,
 gboolean meta_display_remove_keybinding (MetaDisplay         *display,
                                          const char          *name);
 
+guint    meta_display_grab_accelerator   (MetaDisplay *display,
+                                          const char  *accelerator);
+gboolean meta_display_ungrab_accelerator (MetaDisplay *display,
+                                          guint        action_id);
+
 guint meta_display_get_keybinding_action (MetaDisplay  *display,
                                           unsigned int  keycode,
                                           unsigned long mask);
