@@ -93,6 +93,8 @@ guint meta_unsigned_long_hash  (gconstpointer v);
 const char* meta_frame_type_to_string (MetaFrameType type);
 const char* meta_gravity_to_string (int gravity);
 
+char* meta_external_binding_name_for_action (guint keybinding_action);
+
 #include <libintl.h>
 #define _(x) dgettext (GETTEXT_PACKAGE, x)
 #define N_(x) x
@@ -107,6 +109,7 @@ GPid meta_show_dialog (const char *type,
                        const char *display,
                        const char *ok_text,
                        const char *cancel_text,
+                       const char *icon_name,
                        const int transient_for,
                        GSList *columns,
                        GSList *entries);
