@@ -52,6 +52,9 @@ GType meta_workspace_get_type (void);
 int  meta_workspace_index (MetaWorkspace *workspace);
 MetaScreen *meta_workspace_get_screen (MetaWorkspace *workspace);
 GList* meta_workspace_list_windows (MetaWorkspace *workspace);
+void meta_workspace_get_work_area_for_monitor (MetaWorkspace *workspace,
+                                               int            which_monitor,
+                                               MetaRectangle *area);
 void meta_workspace_get_work_area_all_monitors (MetaWorkspace *workspace,
                                                 MetaRectangle *area);
 void meta_workspace_activate (MetaWorkspace *workspace, guint32 timestamp);
