@@ -3,6 +3,34 @@
 
 #include "mutter-enum-types.h"
 
+/* enumerations from "meta/barrier.h" */
+#include "meta/barrier.h"
+
+GType
+meta_barrier_direction_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GFlagsValue values[] = {
+        { META_BARRIER_DIRECTION_POSITIVE_X, "META_BARRIER_DIRECTION_POSITIVE_X", "positive-x" },
+        { META_BARRIER_DIRECTION_POSITIVE_Y, "META_BARRIER_DIRECTION_POSITIVE_Y", "positive-y" },
+        { META_BARRIER_DIRECTION_NEGATIVE_X, "META_BARRIER_DIRECTION_NEGATIVE_X", "negative-x" },
+        { META_BARRIER_DIRECTION_NEGATIVE_Y, "META_BARRIER_DIRECTION_NEGATIVE_Y", "negative-y" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_flags_register_static (g_intern_static_string ("MetaBarrierDirection"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
 /* enumerations from "meta/boxes.h" */
 #include "meta/boxes.h"
 
@@ -552,29 +580,27 @@ meta_exit_code_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "meta/meta-background-actor.h" */
-#include "meta/meta-background-actor.h"
+/* enumerations from "meta/meta-background.h" */
+#include "meta/meta-background.h"
 
 GType
-meta_snippet_hook_get_type (void)
+meta_background_effects_get_type (void)
 {
   static volatile gsize g_enum_type_id__volatile = 0;
 
   if (g_once_init_enter (&g_enum_type_id__volatile))
     {
-      static const GEnumValue values[] = {
-        { META_SNIPPET_HOOK_VERTEX, "META_SNIPPET_HOOK_VERTEX", "vertex" },
-        { META_SNIPPET_HOOK_VERTEX_TRANSFORM, "META_SNIPPET_HOOK_VERTEX_TRANSFORM", "vertex-transform" },
-        { META_SNIPPET_HOOK_FRAGMENT, "META_SNIPPET_HOOK_FRAGMENT", "fragment" },
-        { META_SNIPPET_HOOK_TEXTURE_COORD_TRANSFORM, "META_SNIPPET_HOOK_TEXTURE_COORD_TRANSFORM", "texture-coord-transform" },
-        { META_SNIPPET_HOOK_LAYER_FRAGMENT, "META_SNIPPET_HOOK_LAYER_FRAGMENT", "layer-fragment" },
-        { META_SNIPPET_HOOK_TEXTURE_LOOKUP, "META_SNIPPET_HOOK_TEXTURE_LOOKUP", "texture-lookup" },
+      static const GFlagsValue values[] = {
+        { META_BACKGROUND_EFFECTS_NONE, "META_BACKGROUND_EFFECTS_NONE", "none" },
+        { META_BACKGROUND_EFFECTS_DESATURATE, "META_BACKGROUND_EFFECTS_DESATURATE", "desaturate" },
+        { META_BACKGROUND_EFFECTS_BLUR, "META_BACKGROUND_EFFECTS_BLUR", "blur" },
+        { META_BACKGROUND_EFFECTS_VIGNETTE, "META_BACKGROUND_EFFECTS_VIGNETTE", "vignette" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
 
       g_enum_type_id =
-        g_enum_register_static (g_intern_static_string ("MetaSnippetHook"), values);
+        g_flags_register_static (g_intern_static_string ("MetaBackgroundEffects"), values);
 
       g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
     }
